#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME="gotify/server"
}

do_install_detail() {
  local config=`uci get gotify.@gotify[0].config_path 2>/dev/null`
  local port=`uci get gotify.@gotify[0].port 2>/dev/null`
  local IMAGE_NAME=`uci get gotify.@gotify[0].image_name 2>/dev/null`
  local username=`uci get gotify.@gotify[0].username 2>/dev/null`
  local password=`uci get gotify.@gotify[0].password 2>/dev/null`

  #Generate the generic environment variables for the docker-compose

  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  # Get our local LAN IP Address
  LAN_IP=$(uci get network.lan.ipaddr)
  # Strip trailing network mask
  LAN_IP="${LAN_IP%/*}"
   
  if [ -z "$config" ]; then
      echo "config path is empty!"
      exit 1
  fi

  [ -z "$port" ] && port=8050
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME=gotify/server

  
  # Create Docker Compose file with custom variables
   
  # Create Docker Compose file with custom variables
cat > docker-compose.yml <<EOF
version: "3"
services:
  app:
    image: gotify/server
    container_name: gotify
    restart: unless-stopped
    ports:
      - ${LAN_IP}:$port:80
    environment:
      - TZ='Africa/Casablanca'
    volumes:
      - ./data:/app/data
    labels:
      plugsy.name: "Gotify"
      plugsy.category: "Home"
      plugsy.icon: "@styled-icons/material-sharp/Notifications"
      plugsy.link: "http://${LAN_IP}:$port"

EOF
  
  docker-compose up -d
 
  # Add a new list option to the "shortcutmenu" configuration file
  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$LAN_IP:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install gotify"
  echo "      upgrade                Upgrade gotify"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart gotify"
  echo "      status                 gotify status"
  echo "      port                   gotify port"
}

case ${ACTION} in
  "install")
    get_image
    do_install_detail
  ;;
  "upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    docker rm -f gotify
  ;;
  "start" | "stop" | "restart")
    docker ${ACTION} gotify
  ;;
  "status")
    docker ps --all -f 'name=gotify' --format '{{.State}}'
  ;;
  "port")
    docker ps --all -f 'name=gotify' --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac
